@@ -2,10 +2,17 @@ package Dancer::Serializer::XML;
 
 use strict;
 use warnings;
-use XML::Simple;
+use Dancer::ModuleLoader;
 use base 'Dancer::Serializer::Abstract';
 
-my $xml_serializer = XML::Simple->new( ForceArray => 0, );
+my $xml_serializer;
+
+sub init {
+    die 'XML::Simple is needed and is not installed'
+      unless Dancer::ModuleLoader->load('XML::Simple');
+
+    $xml_serializer = XML::Simple->new( ForceArray => 0 );
+}
 
 sub serialize {
     my ( $self, $entity ) = @_;
@@ -17,8 +24,6 @@ sub deserialize {
     $xml_serializer->XMLin($content);
 }
 
-sub content_type {
-    "text/xml";
-}
+sub content_type { 'text/xml' }
 
 1;
